@@ -1,8 +1,5 @@
 #! /bin/sh
-#
-# Automated Testing Framework (atf)
-#
-# Copyright (c) 2007, 2008, 2009 The NetBSD Foundation, Inc.
+# Copyright (c) 2007 The NetBSD Foundation, Inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -26,7 +23,6 @@
 # IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 # OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
 # IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-#
 
 #
 # A utility to sanity check the coding style of all source files in the
@@ -100,8 +96,9 @@ find_sources() {
               \! -path "*autom4te*" -a \
               -type f -a \
               \! -name "aclocal.m4" \
-              \! -name "bconfig.h" \
+              \! -name "config.h" \
               \! -name "defs.h" \
+              \! -name "defs.hpp" \
               \! -name "libtool.m4" \
               \! -name "ltoptions.m4" \
               \! -name "ltsugar.m4" \
