@@ -1,7 +1,4 @@
-//
-// Automated Testing Framework (atf)
-//
-// Copyright (c) 2007, 2008, 2010 The NetBSD Foundation, Inc.
+// Copyright (c) 2007 The NetBSD Foundation, Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -25,10 +22,9 @@
 // IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 // OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
 // IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-//
 
-#if !defined(_ATF_CXX_MACROS_HPP_)
-#define _ATF_CXX_MACROS_HPP_
+#if !defined(ATF_CXX_MACROS_HPP)
+#define ATF_CXX_MACROS_HPP
 
 #include <sstream>
 #include <stdexcept>
@@ -36,31 +32,48 @@
 
 #include <atf-c++/tests.hpp>
 
+// Do not define inline methods for the test case classes.  Doing so
+// significantly increases the memory requirements of GNU G++ during
+// compilation.
+
 #define ATF_TEST_CASE_WITHOUT_HEAD(name) \
+    namespace { \
     class atfu_tc_ ## name : public atf::tests::tc { \
         void body(void) const; \
     public: \
-        atfu_tc_ ## name(void) : atf::tests::tc(#name, false) {} \
-    };
+        atfu_tc_ ## name(void); \
+    }; \
+    static atfu_tc_ ## name* atfu_tcptr_ ## name; \
+    atfu_tc_ ## name::atfu_tc_ ## name(void) : atf::tests::tc(#name, false) {} \
+    }
 
 #define ATF_TEST_CASE(name) \
+    namespace { \
     class atfu_tc_ ## name : public atf::tests::tc { \
         void head(void); \
         void body(void) const; \
     public: \
-        atfu_tc_ ## name(void) : atf::tests::tc(#name, false) {} \
-    };
+        atfu_tc_ ## name(void); \
+    }; \
+    static atfu_tc_ ## name* atfu_tcptr_ ## name; \
+    atfu_tc_ ## name::atfu_tc_ ## name(void) : atf::tests::tc(#name, false) {} \
+    }
 
 #define ATF_TEST_CASE_WITH_CLEANUP(name) \
+    namespace { \
     class atfu_tc_ ## name : public atf::tests::tc { \
         void head(void); \
         void body(void) const; \
         void cleanup(void) const; \
     public: \
-        atfu_tc_ ## name(void) : atf::tests::tc(#name, true) {} \
-    };
+        atfu_tc_ ## name(void); \
+    }; \
+    static atfu_tc_ ## name* atfu_tcptr_ ## name; \
+    atfu_tc_ ## name::atfu_tc_ ## name(void) : atf::tests::tc(#name, true) {} \
+    }
 
 #define ATF_TEST_CASE_NAME(name) atfu_tc_ ## name
+#define ATF_TEST_CASE_USE(name) (atfu_tcptr_ ## name) = NULL
 
 #define ATF_TEST_CASE_HEAD(name) \
     void \
@@ -82,59 +95,111 @@
 
 #define ATF_PASS() atf::tests::tc::pass()
 
-#define ATF_REQUIRE(x) \
+#define ATF_REQUIRE(expression) \
     do { \
-        if (!(x)) { \
+        if (!(expression)) { \
             std::ostringstream atfu_ss; \
-            atfu_ss << "Line " << __LINE__ << ": " << #x << " not met"; \
+            atfu_ss << "Line " << __LINE__ << ": " << #expression \
+                    << " not met"; \
             atf::tests::tc::fail(atfu_ss.str()); \
         } \
     } while (false)
 
-#define ATF_REQUIRE_EQ(x, y) \
+#define ATF_REQUIRE_EQ(expected, actual) \
     do { \
-        if ((x) != (y)) { \
+        if ((expected) != (actual)) { \
             std::ostringstream atfu_ss; \
-            atfu_ss << "Line " << __LINE__ << ": " << #x << " != " << #y \
-                     << " (" << (x) << " != " << (y) << ")"; \
+            atfu_ss << "Line " << __LINE__ << ": " \
+                    << #expected << " != " << #actual \
+                    << " (" << (expected) << " != " << (actual) << ")"; \
             atf::tests::tc::fail(atfu_ss.str()); \
         } \
     } while (false)
 
-#define ATF_REQUIRE_THROW(e, x) \
+#define ATF_REQUIRE_IN(element, collection) \
+    ATF_REQUIRE((collection).find(element) != (collection).end())
+
+#define ATF_REQUIRE_NOT_IN(element, collection) \
+    ATF_REQUIRE((collection).find(element) == (collection).end())
+
+#define ATF_REQUIRE_MATCH(regexp, string) \
+    do { \
+        if (!atf::tests::detail::match(regexp, string)) { \
+            std::ostringstream atfu_ss; \
+            atfu_ss << "Line " << __LINE__ << ": '" << string << "' does not " \
+                    << "match regexp '" << regexp << "'"; \
+            atf::tests::tc::fail(atfu_ss.str()); \
+        } \
+    } while (false)
+
+#define ATF_REQUIRE_THROW(expected_exception, statement) \
     do { \
         try { \
-            x; \
+            statement; \
             std::ostringstream atfu_ss; \
-            atfu_ss << "Line " << __LINE__ << ": " #x " did not throw " \
-                        #e " as expected"; \
+            atfu_ss << "Line " << __LINE__ \
+                    << ": " #statement " did not throw " #expected_exception \
+                       " as expected"; \
             atf::tests::tc::fail(atfu_ss.str()); \
-        } catch (const e&) { \
+        } catch (const expected_exception&) { \
         } catch (const std::exception& atfu_e) { \
             std::ostringstream atfu_ss; \
-            atfu_ss << "Line " << __LINE__ << ": " #x " threw an " \
-                        "unexpected error (not " #e "): " << atfu_e.what(); \
+            atfu_ss << "Line " << __LINE__ << ": " #statement " threw an " \
+                       "unexpected error (not " #expected_exception "): " \
+                    << atfu_e.what(); \
             atf::tests::tc::fail(atfu_ss.str()); \
         } catch (...) { \
             std::ostringstream atfu_ss; \
-            atfu_ss << "Line " << __LINE__ << ": " #x " threw an " \
-                        "unexpected error (not " #e ")"; \
+            atfu_ss << "Line " << __LINE__ << ": " #statement " threw an " \
+                       "unexpected error (not " #expected_exception ")"; \
             atf::tests::tc::fail(atfu_ss.str()); \
         } \
     } while (false)
 
-#define ATF_CHECK_ERRNO(exp_errno, bool_expr) \
-    atf::tests::tc::check_errno(__FILE__, __LINE__, exp_errno, #bool_expr, \
-                                bool_expr)
+#define ATF_REQUIRE_THROW_RE(expected_exception, regexp, statement) \
+    do { \
+        try { \
+            statement; \
+            std::ostringstream atfu_ss; \
+            atfu_ss << "Line " << __LINE__ \
+                    << ": " #statement " did not throw " #expected_exception \
+                       " as expected"; \
+            atf::tests::tc::fail(atfu_ss.str()); \
+        } catch (const expected_exception& e) { \
+            if (!atf::tests::detail::match(regexp, e.what())) { \
+                std::ostringstream atfu_ss; \
+                atfu_ss << "Line " << __LINE__ \
+                        << ": " #statement " threw " #expected_exception "(" \
+                        << e.what() << "), but does not match '" << regexp \
+                        << "'"; \
+                atf::tests::tc::fail(atfu_ss.str()); \
+            } \
+        } catch (const std::exception& atfu_e) { \
+            std::ostringstream atfu_ss; \
+            atfu_ss << "Line " << __LINE__ << ": " #statement " threw an " \
+                        "unexpected error (not " #expected_exception "): " \
+                    << atfu_e.what(); \
+            atf::tests::tc::fail(atfu_ss.str()); \
+        } catch (...) { \
+            std::ostringstream atfu_ss; \
+            atfu_ss << "Line " << __LINE__ << ": " #statement " threw an " \
+                        "unexpected error (not " #expected_exception ")"; \
+            atf::tests::tc::fail(atfu_ss.str()); \
+        } \
+    } while (false)
 
-#define ATF_REQUIRE_ERRNO(exp_errno, bool_expr) \
-    atf::tests::tc::require_errno(__FILE__, __LINE__, exp_errno, #bool_expr, \
-                                  bool_expr)
+#define ATF_CHECK_ERRNO(expected_errno, bool_expr) \
+    atf::tests::tc::check_errno(__FILE__, __LINE__, expected_errno, \
+                                #bool_expr, bool_expr)
+
+#define ATF_REQUIRE_ERRNO(expected_errno, bool_expr) \
+    atf::tests::tc::require_errno(__FILE__, __LINE__, expected_errno, \
+                                  #bool_expr, bool_expr)
 
 #define ATF_INIT_TEST_CASES(tcs) \
     namespace atf { \
         namespace tests { \
-            int run_tp(int, char* const*, \
+            int run_tp(int, char**, \
                        void (*)(std::vector< atf::tests::tc * >&)); \
         } \
     } \
@@ -142,7 +207,7 @@
     static void atfu_init_tcs(std::vector< atf::tests::tc * >&); \
     \
     int \
-    main(int argc, char* const* argv) \
+    main(int argc, char** argv) \
     { \
         return atf::tests::run_tp(argc, argv, atfu_init_tcs); \
     } \
@@ -153,8 +218,8 @@
 
 #define ATF_ADD_TEST_CASE(tcs, tcname) \
     do { \
-        atf::tests::tc* tcptr = new atfu_tc_ ## tcname(); \
-        (tcs).push_back(tcptr); \
+        atfu_tcptr_ ## tcname = new atfu_tc_ ## tcname(); \
+        (tcs).push_back(atfu_tcptr_ ## tcname); \
     } while (0);
 
-#endif // !defined(_ATF_CXX_MACROS_HPP_)
+#endif // !defined(ATF_CXX_MACROS_HPP)
