@@ -1,7 +1,4 @@
-/*
- * Automated Testing Framework (atf)
- *
- * Copyright (c) 2007, 2008, 2009, 2010, 2011 The NetBSD Foundation, Inc.
+/* Copyright (c) 2007 The NetBSD Foundation, Inc.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -24,8 +21,9 @@
  * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
  * IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
  * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
- * IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+ * IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.  */
+
+#include "atf-c/detail/process.h"
 
 #include <sys/types.h>
 #include <sys/wait.h>
@@ -38,11 +36,9 @@
 #include <unistd.h>
 
 #include "atf-c/defs.h"
+#include "atf-c/detail/sanity.h"
 #include "atf-c/error.h"
 
-#include "process.h"
-#include "sanity.h"
-
 /* This prototype is not in the header file because this is a private
  * function; however, we need to access it during testing. */
 atf_error_t atf_process_status_init(atf_process_status_t *, int);
@@ -197,7 +193,7 @@ atf_process_status_init(atf_process_status_t *s, int status)
 }
 
 void
-atf_process_status_fini(atf_process_status_t *s)
+atf_process_status_fini(atf_process_status_t *s ATF_DEFS_ATTRIBUTE_UNUSED)
 {
 }
 
@@ -411,24 +407,6 @@ out:
     return err;
 }
 
-static
-atf_error_t
-silence_stdin(void)
-{
-    atf_error_t err;
-
-    close(STDIN_FILENO);
-    int fd = open("/dev/zero", O_RDONLY);
-    if (fd == -1)
-        err = atf_libc_error(errno, "Could not open /dev/zero");
-    else {
-        INV(fd == STDIN_FILENO);
-        err = atf_no_error();
-    }
-
-    return err;
-}
-
 static
 void
 do_child(void (*)(void *),
@@ -445,10 +423,6 @@ do_child(void (*start)(void *),
 {
     atf_error_t err;
 
-    err = silence_stdin();
-    if (atf_is_error(err))
-        goto out;
-
     err = child_connect(outsp, STDOUT_FILENO);
     if (atf_is_error(err))
         goto out;
